# OE1100
###############################################################################################################################
# Copyright 2021 Orchid Systems 
# -----------------------------
# Additional funcationality includes:
# (2021-8-05) - State field finder on O/E ship-to popup. Looks up the state in an optional field called, VALIDSTATES
#
# -------------------------------------------------------
# Permitted for use with Orchid Systems Modules only.
# The code is supplied on an "as is" basis for training and demonstration purposes only and is not supported by Orchid Systems.
# If this code is deployed in a live production environment it is the responsibility of the End User to ensure 
# that it is operating as required.
###############################################################################################################################
from accpac import *

### Globals ###

# name of optional field with valid states for ship-to field.
stateOptField = "VALIDSTATES"

def main(args):
	MyUI()

class MyUI(UI):
	def __init__(self):
		UI.__init__(self)
		self.createScreen()

	def createScreen(self):
		#ctrl = self.getHostControl("controlname")
		self.dsH = self.openDataSource("adsOEORDH")
		self.dsH.onBefore = self.dsH_onBefore
		
		self.onEvent("onPopupOpened", self.onPopupOpened)
		self.show()

	def dsH_onBefore(self, eventname, field, value):
	
		if eventname == "PUT":
			if field == "SHPSTATE":
				return self.validState(value)
		
	def onPopupOpened(self, e):
		e = parseArgs(e)
		if e["strPopupName"] == "frmShpAddr":
			self.addExtraFeatures()
			#self.getControlInfo("", self.onPopupControls) # This will list all controls on the form
		
	def onPopupControls(self, info):
		s = ""
		for c in info.items:
			s = s + "\n" + c.name
		showMessageBox(s)
		
	def addExtraFeatures(self):
		fecState = self.getHostControlField("fecOEORDH_ShpToState")
		fecState.showFinderButton()
		fecState.setOnClick(self.fecState_onClick)
		
	def fecState_onClick(self, e):
		if e.button == 4:
			## Finder button.
			finder = Finder()
			finder.viewID = "CS0012"
			finder.filter = "OPTFIELD = \"{}\"".format(stateOptField)
			finder.displayFields = "2,4"
			finder.returnFields = "2"
			finder.onOK = self.fecState_finder_ok
			finder.onCancel = self.fecState_finder_cancel
			
			finder.show(self)
			
	def fecState_finder_ok(self, e):
		r = self.dsH.dsput("SHPSTATE", e)
		if r == 0:
			self.setButtonClickResultToCancelWithTabAway()
		else:
			self.setButtonClickResultToCancelWithSetFocus()
		
	def fecState_finder_cancel(self):
		self.setButtonClickResultToCancel()
		
	def validState(self, stateName):
		# Example code if you want to validate the selected value. This leaves the focus on the field rather that on the next field. 
		# Replace with your own validation routine
		# e.g. only certain states for certain users, certain customer types
		if stateName.lower() == "california":
			error("State {} is not valid for this order. Choose another state".format(stateName))
			return False
		
		v = openView("CS0012", 1)
		
		sFilter = "OPTFIELD = \"{}\" AND VALUE = \"{}\"".format(stateOptField, stateName)
		v.recordClear()
		v.browse(sFilter, 1)
		if v.fetch() != 0:
			## state not found in the optional field table.
			msg = "Invalid Entry. State [{}] not found in list of states in optional field [{}]".format(stateName, stateOptField)
			error(msg)
			return False
		else:
			return True

def showMyMessage(msg, title = ""):
	if isWeb == False:
		showMessageBox(msg, title)
	else:
		message(msg)
